@@ -10,8 +10,6 @@ from zope.interface import implementer
 from zope.intid.interfaces import IIntIds
 from zope.publisher.interfaces.browser import IBrowserRequest
 
-import six
-
 
 @implementer(IFieldDeserializer)
 @adapter(IRelationChoice, IDexterityContent, IBrowserRequest)
@@ -29,9 +27,7 @@ class RelationChoiceFieldDeserializer(DefaultFieldDeserializer):
             intids = queryUtility(IIntIds)
             obj = intids.queryObject(value)
             resolved_by = "intid"
-        elif isinstance(value, six.string_types):
-            if six.PY2 and isinstance(value, six.text_type):
-                value = value.encode("utf8")
+        elif isinstance(value, str):
             portal = getMultiAdapter(
                 (self.context, self.request), name="plone_portal_state"
             ).portal()
@@ -54,9 +50,7 @@ class RelationChoiceFieldDeserializer(DefaultFieldDeserializer):
 
         if obj is None:
             self.request.response.setStatus(400)
-            raise ValueError(
-                u"Could not resolve object for {}={}".format(resolved_by, value)
-            )
+            raise ValueError(f"Could not resolve object for {resolved_by}={value}")
 
         self.field.validate(obj)
         return obj
