@@ -10,9 +10,12 @@ from plone.restapi.services.discussion.utils import can_edit
 from plone.restapi.services.discussion.utils import can_reply
 from plone.restapi.services.discussion.utils import delete_own_comment_allowed
 from plone.restapi.services.discussion.utils import edit_comment_allowed
+from plone.restapi.services.users.get import getPortraitUrl
+from plone.restapi.services.users.get import isDefaultPortrait
 from Products.CMFCore.utils import getToolByName
 from zope.component import adapter
 from zope.component import getMultiAdapter
+from zope.component.hooks import getSite
 from zope.interface import implementer
 from zope.publisher.interfaces import IRequest
 
@@ -104,8 +107,11 @@ class CommentSerializer:
     def get_author_image(self, username=None):
         if username is None:
             return
-        portal_membership = getToolByName(self.context, "portal_membership", None)
-        image = portal_membership.getPersonalPortrait(username).absolute_url()
-        if image.endswith("defaultUser.png"):
-            return
-        return image
+        portal = getSite()
+        portal_membership = getToolByName(portal, "portal_membership", None)
+        image = portal_membership.getPersonalPortrait(username)
+        if image and not isDefaultPortrait(image):
+            # Despite being called username, it is actually a userid.
+            # See https://github.com/plone/plone.app.discussion/blob/dd0255fd5db6662a1b1b4cb7046785038d0d6b71/plone/app/discussion/browser/comments.py#L211-L217
+            user = portal_membership.getMemberById(username)
+            return getPortraitUrl(user)
