@@ -119,6 +119,9 @@ def get_form_fieldsets(form):
         fieldset = {
             "id": group.__name__,
             "title": translate(group.label, context=getRequest()),
+            "description": translate(group.description, context=getRequest())
+            if group.description is not None
+            else "",
             "fields": list(group.fields.values()),
             "behavior": "plone",
         }
